Learn R Programming

pawscore (version 1.0.3)

create_pain_model: Create a new pain model

Description

Create a new pain model based on a set of paw features, corresponding pain stimuli, and corresponding strain identity.

Usage

create_pain_model(
  paw.features,
  strains = NULL,
  pain.stimulus = NULL,
  strain.standards = jones2020.standards,
  feature.set = c("post.peak", "pre.peak")
)

Value

pain model

Arguments

paw.features

the paw features returned by extract_features

strains

a vector containing strain information for each mouse

pain.stimulus

a vector containing stimulus information for each mouse

strain.standards

z-scores (centering and scaling) information by strain

feature.set

use either pre-peak or post-peak features