Learn R Programming

pawscore (version 1.0.3)

create_strain_standard: Create new strain standards

Description

Creates a new reference centering and scaling for the paw features of the given strain or strains.

Usage

create_strain_standard(paw.features, strain)

Value

list of pre-peak and post-peak strain standards, indexed by strain

Arguments

paw.features

list of extracted paw features

strain

character string or a vector of strain names, each of which is a character string, matching in length and order the list of paw features.