Returns a pain score based on Jones et al. 2020 or the given pain.model. Pain scores are standardized so that increasingly positive (negative) values correspond to increasingly likely to be painful (unlikely to be painful) experiences. Pain scores based on pain models derived from trinary pain stimuli will additionally be scaled such that the transition between low and high pain is occurs at 1. Scores are not comparable across pain models.
pain_score(
paw.features,
strains = NULL,
strain.standards = jones2020.standards,
feature.set = c("post.peak", "pre.peak"),
pain.model = NULL
)one or more pain scores as a vector
the paw features returned by
extract_features
a vector containing strain information for each mouse
z-scores (centering and scaling) information by strain
use either pre-peak or post-peak features
a pain model returned by create_pain_model
or NULL, in which case the model from Jones et al. 2020 is used.