Create a new pain model based on a set of paw features, corresponding pain stimuli, and corresponding strain identity.
create_pain_model(
paw.features,
strains = NULL,
pain.stimulus = NULL,
strain.standards = jones2020.standards,
feature.set = c("post.peak", "pre.peak")
)pain model
the paw features returned by
extract_features
a vector containing strain information for each mouse
a vector containing stimulus information for each mouse
z-scores (centering and scaling) information by strain
use either pre-peak or post-peak features