Creates a new reference centering and scaling for the paw features of the given strain or strains.
create_strain_standard(paw.features, strain)list of pre-peak and post-peak strain standards, indexed by strain
list of extracted paw features
character string or a vector of strain names, each of which is a character string, matching in length and order the list of paw features.